==> knative-model-6.0.0-sources.jar: io/fabric8/knative/internal/pkg/apis/duck/v1/DestinationFluentImpl.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DestinationFluentImpl<A extends DestinationFluent<A>> extends BaseFluent<A> implements DestinationFluent<A>{
  public DestinationFluentImpl() {
  }
  public DestinationFluentImpl(Destination instance) {
    this.withRef(instance.getRef()); 
    this.withUri(instance.getUri()); 
  }
  private KReferenceBuilder ref;
  private String uri;
  
  /**
   * This method has been deprecated, please use method buildRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public KReference getRef() {
    return this.ref!=null ?this.ref.build():null;
  }
  public KReference buildRef() {
    return this.ref!=null ?this.ref.build():null;
  }
  public A withRef(KReference ref) {
    _visitables.get("ref").remove(this.ref);
    if (ref!=null){ this.ref= new KReferenceBuilder(ref); _visitables.get("ref").add(this.ref);} else { this.ref = null; _visitables.get("ref").remove(this.ref); } return (A) this;
  }
  public Boolean hasRef() {
    return this.ref != null;
  }
  public A withNewRef(String apiVersion,String kind,String name,String namespace) {
    return (A)withRef(new KReference(apiVersion, kind, name, namespace));
  }
  public DestinationFluent.RefNested<A> withNewRef() {
    return new DestinationFluentImpl.RefNestedImpl();
  }
  public DestinationFluent.RefNested<A> withNewRefLike(KReference item) {
    return new DestinationFluentImpl.RefNestedImpl(item);
  }
  public DestinationFluent.RefNested<A> editRef() {
    return withNewRefLike(getRef());
  }
  public DestinationFluent.RefNested<A> editOrNewRef() {
    return withNewRefLike(getRef() != null ? getRef(): new KReferenceBuilder().build());
  }
  public DestinationFluent.RefNested<A> editOrNewRefLike(KReference item) {
    return withNewRefLike(getRef() != null ? getRef(): item);
  }
  public String getUri() {
    return this.uri;
  }
  public A withUri(String uri) {
    this.uri=uri; return (A) this;
  }
  public Boolean hasUri() {
    return this.uri != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DestinationFluentImpl that = (DestinationFluentImpl) o;
    if (ref != null ? !ref.equals(that.ref) :that.ref != null) return false;
    if (uri != null ? !uri.equals(that.uri) :that.uri != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ref,  uri,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (ref != null) { sb.append("ref:"); sb.append(ref + ","); }
    if (uri != null) { sb.append("uri:"); sb.append(uri); }
    sb.append("}");
    return sb.toString();
  }
  class RefNestedImpl<N> extends KReferenceFluentImpl<DestinationFluent.RefNested<N>> implements DestinationFluent.RefNested<N>,Nested<N>{
    RefNestedImpl(KReference item) {
      this.builder = new KReferenceBuilder(this, item);
    }
    RefNestedImpl() {
      this.builder = new KReferenceBuilder(this);
    }
    KReferenceBuilder builder;
    public N and() {
      return (N) DestinationFluentImpl.this.withRef(builder.build());
    }
    public N endRef() {
      return and();
    }
    
  }
  
}

==> knative-model-6.3.1-sources.jar: io/fabric8/knative/internal/pkg/apis/duck/v1/DestinationFluentImpl.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DestinationFluentImpl<A extends DestinationFluent<A>> extends BaseFluent<A> implements DestinationFluent<A>{
  public DestinationFluentImpl() {
  }
  public DestinationFluentImpl(Destination instance) {
    this.withRef(instance.getRef()); 
    this.withUri(instance.getUri()); 
  }
  private KReferenceBuilder ref;
  private String uri;
  
  /**
   * This method has been deprecated, please use method buildRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public KReference getRef() {
    return this.ref!=null ?this.ref.build():null;
  }
  public KReference buildRef() {
    return this.ref!=null ?this.ref.build():null;
  }
  public A withRef(KReference ref) {
    _visitables.get("ref").remove(this.ref);
    if (ref!=null){ this.ref= new KReferenceBuilder(ref); _visitables.get("ref").add(this.ref);} else { this.ref = null; _visitables.get("ref").remove(this.ref); } return (A) this;
  }
  public Boolean hasRef() {
    return this.ref != null;
  }
  public A withNewRef(String apiVersion,String group,String kind,String name,String namespace) {
    return (A)withRef(new KReference(apiVersion, group, kind, name, namespace));
  }
  public DestinationFluent.RefNested<A> withNewRef() {
    return new DestinationFluentImpl.RefNestedImpl();
  }
  public DestinationFluent.RefNested<A> withNewRefLike(KReference item) {
    return new DestinationFluentImpl.RefNestedImpl(item);
  }
  public DestinationFluent.RefNested<A> editRef() {
    return withNewRefLike(getRef());
  }
  public DestinationFluent.RefNested<A> editOrNewRef() {
    return withNewRefLike(getRef() != null ? getRef(): new KReferenceBuilder().build());
  }
  public DestinationFluent.RefNested<A> editOrNewRefLike(KReference item) {
    return withNewRefLike(getRef() != null ? getRef(): item);
  }
  public String getUri() {
    return this.uri;
  }
  public A withUri(String uri) {
    this.uri=uri; return (A) this;
  }
  public Boolean hasUri() {
    return this.uri != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DestinationFluentImpl that = (DestinationFluentImpl) o;
    if (ref != null ? !ref.equals(that.ref) :that.ref != null) return false;
    if (uri != null ? !uri.equals(that.uri) :that.uri != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ref,  uri,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (ref != null) { sb.append("ref:"); sb.append(ref + ","); }
    if (uri != null) { sb.append("uri:"); sb.append(uri); }
    sb.append("}");
    return sb.toString();
  }
  class RefNestedImpl<N> extends KReferenceFluentImpl<DestinationFluent.RefNested<N>> implements DestinationFluent.RefNested<N>,Nested<N>{
    RefNestedImpl(KReference item) {
      this.builder = new KReferenceBuilder(this, item);
    }
    RefNestedImpl() {
      this.builder = new KReferenceBuilder(this);
    }
    KReferenceBuilder builder;
    public N and() {
      return (N) DestinationFluentImpl.this.withRef(builder.build());
    }
    public N endRef() {
      return and();
    }
    
  }
  
}
